@@ -183,49 +183,56 @@ class Manager:
             except Exception as e:
                 logging.error(e)
 
-    def monitor(self, func):
+    def monitor(self, eventKey= None):
         '''
             to monitor an method.
             - Returns: <class 'tuple'>, will return the monitored methods handle result and trigger handle results.
         '''
-        @functools.wraps(func)
-        def wapper(*args, **kwargs):
-            _handleName = func.__qualname__.replace('.', '_').upper()
-            ret = self.on(_handleName, "BEFORE", *args, **kwargs)
-            kwargs['trigger_results'] = []
-            kwargs['trigger_results'].append({'BEFORE': ret[1]['results']})
-            if ret[0]:
-                ret = func(*args, **kwargs)
-                # TODO checked results.
-                kwargs['master_func_results'] = ret
-                # to add func results mapping.
-                if self._event_cache[_handleName]['resultChecked']:
-                    func_result_checked = self._checked_handle_result(
-                        self._event_cache[_handleName]['resultChecked'], ret)
-                    if func_result_checked[0]:
-                        func_result_checked = self.on(
-                            _handleName, 'SUCCESS', *args, **kwargs)
-                        kwargs['trigger_results'].append(
-                            {'SUCCESS': func_result_checked[1]['results']})
-                        if not func_result_checked[0]:
-                            ret = None
-                    else:
-                        func_result_checked = self.on(
-                            _handleName, 'FAILED', *args, **kwargs)
-                        kwargs['trigger_results'].append(
-                            {'FAILED': func_result_checked[1]['results']})
-                        if not func_result_checked[0]:
-                            ret = None
-                func_result_checked = self.on(
-                    _handleName, "COMPLETE", *args, **kwargs)
-                kwargs['trigger_results'].append(
-                    {'COMPLETE': func_result_checked[1]['results']})
-                if not func_result_checked[0]:
+        def decorator(func):
+            @functools.wraps(func)
+            def wapper(*args, **kwargs):
+                if eventKey:
+                    _handleName = func.__qualname__.split('.')[0].upper()+'_'+ eventKey.upper()
+                else:
+                    _handleName = func.__qualname__.replace('.', '_').upper()
+                ret = self.on(_handleName, "BEFORE", *args, **kwargs)
+                kwargs['trigger_results'] = []
+                kwargs['trigger_results'].append({'BEFORE': ret[1]['results']})
+                if ret[0]:
+                    ret = func(*args, **kwargs)
+                    # TODO checked results.
+                    kwargs['master_func_results'] = ret
+                    # to add func results mapping.
+                    if _handleName not in self._event_cache:
+                        return ret
+                    if self._event_cache[_handleName]['resultChecked']:
+                        func_result_checked = self._checked_handle_result(
+                            self._event_cache[_handleName]['resultChecked'], ret)
+                        if func_result_checked[0]:
+                            func_result_checked = self.on(
+                                _handleName, 'SUCCESS', *args, **kwargs)
+                            kwargs['trigger_results'].append(
+                                {'SUCCESS': func_result_checked[1]['results']})
+                            if not func_result_checked[0]:
+                                ret = None
+                        else:
+                            func_result_checked = self.on(
+                                _handleName, 'FAILED', *args, **kwargs)
+                            kwargs['trigger_results'].append(
+                                {'FAILED': func_result_checked[1]['results']})
+                            if not func_result_checked[0]:
+                                ret = None
+                    func_result_checked = self.on(
+                        _handleName, "COMPLETE", *args, **kwargs)
+                    kwargs['trigger_results'].append(
+                        {'COMPLETE': func_result_checked[1]['results']})
+                    if not func_result_checked[0]:
+                        ret = None
+                else:
                     ret = None
-            else:
-                ret = None
-            return ret, kwargs['trigger_results']
-        return wapper
+                return ret, kwargs['trigger_results']
+            return wapper
+        return decorator
 
     def _func_returns_mapping(self, mapping: dict, *args, **kwargs):
         '''
@@ -248,6 +255,8 @@ class Manager:
         if not handle:
             raise Exception('webEvent.on handle is none.')
         m_event = handle.upper() + "." + event.upper()
+        if handle not in self._event_cache:
+            return True, {"results": "event trigger method is none."}
         if m_event in self._event_cache[handle]:
             default_state = self._event_cache[handle][m_event]['sync']
         else:
