@@ -271,7 +271,7 @@ class RPC:
         RPC. 此类只能配合webservice/rpc使用, 独立使用将会报错.
     '''
 
-    def __init__(self, service_center_uri, secret, logging_config=None):
+    def __init__(self, service_center_uri, secret):
         '''
             初始化
             - params:
@@ -284,17 +284,7 @@ class RPC:
         self._sc_uri = service_center_uri
         self._apisTable = {}
         self._current_service = None
-        self._logging = False
-        if logging_config:
-            self._logging = True
-            logging_setup(logging_config)
 
-    def _log(self, msg, type="info"):
-        if self._logging:
-            if type.lower() == "info":
-                logging.info(msg)
-            elif type.lower() == "error":
-                logging.error(msg)
 
     def _getApi(self, service, method):
         if service+method not in self._apisTable:
@@ -577,7 +567,7 @@ class RPC:
                             m_uri += "?"+params_data
                 try:
                     if m_method == u"GET":
-                        self._log(m_uri)
+                        logging.info("access api:(%s), method(GET)."%m_uri)
                         state, ret = GET(
                             uri=m_uri, http_headers=m_headers, time_out=15)
                         if state == 200:
@@ -593,7 +583,7 @@ class RPC:
                             except:
                                 return {"state": ret['state'], "msg": ret}
                     elif m_method == u"POST":
-                        self._log(m_uri+", postdata:%s" % params_data)
+                        logging.info("access api:(%s), method(POST),postdata:%s."%(m_uri,params_data))
                         state, ret = POST(m_uri, bytes(
                             params_data, encoding='utf-8'), http_headers=m_headers, time_out=15)
                         if state == 200:
@@ -610,10 +600,13 @@ class RPC:
                             except:
                                 return {"state": state, "msg": ret}
                     elif m_method == u"PUT":
+                        logging.info("access api:(%s), method(PUT),postdata:%s."%(m_uri,params_data))
+                        
                         # 还没有写PUT方法
                         raise Exception('urllib PUT方法还没写.')
                     elif m_method == u"DELETE":
                         # 还没有写DELETE方法
+                        logging.info("access api:(%s), method(DELETE)"%m_uri)
                         raise Exception("urllib delete 方法还没写.")
                     else:
                         raise Exception('restful method is error.')
