@@ -105,26 +105,30 @@ class register:
 
 
 class perACL:
-    def __init__(self,rpc_key, params_container_class,tokenKey="usr-token"):
+    def __init__(self, rpc_key, params_container_class, platformKey=None, tokenKey="usr-token"):
         self._params_container = params_container_class
-        self._tokenKey= tokenKey
-        self._rpc= None
-        self._rpc_key= rpc_key
-    
-    def addRPCHandle(self, handle):
-        self._rpc= handle
+        self._platformKey = platformKey
+        self._tokenKey = tokenKey
+        self._rpc = None
+        self._rpc_key = rpc_key
 
-    def AccessControlLists(self, eventKey= None, debug= False):
+    def addRPCHandle(self, handle):
+        self._rpc = handle
+
+    def AccessControlLists(self, premissionKey=None, debug=False):
         def decorator(func):
             @functools.wraps(func)
             def wapper(*args, **kwargs):
-                validate_state= True
+                validate_state = True
                 if not debug:
-                    platkey=func.__qualname__.split('.')[0].upper()
-                    if eventKey:
-                        _handleName = platkey+"."+func.__qualname__.split('.')[0].upper()+'_'+ eventKey.upper()
+                    if self._platformKey:
+                        self._platformKey += "."
+                        self._platformKey= self._platformKey.upper()
+                    if premissionKey:
+                        _handleName = self._platformKey + premissionKey.upper()
                     else:
-                        _handleName = platkey+"."+func.__qualname__.replace('.', '_').upper()
+                        _handleName = self._platformKey + \
+                            func.__qualname__.replace('.', '_').upper()
                     params_instance = None
                     for k in args:
                         if isinstance(k, self._params_container):
@@ -136,32 +140,33 @@ class perACL:
                                 params_instance = v
                                 break
                     if not params_instance:
-                        return Response("can found context.",status= 415)
+                        return Response("can found context.", status=415)
                     if isinstance(params_instance, Request):
                         if self._tokenKey in params_instance._request.headers:
-                            token= params_instance._request.headers[self._tokenKey]
+                            token = params_instance._request.headers[self._tokenKey]
                         else:
-                            return Response("http headers can not found '%s' key."%self._tokenKey,status= 415)
+                            return Response("http headers can not found '%s' key." % self._tokenKey, status=415)
                     elif isinstance(params_instance, dict):
-                        token= params_instance[self._tokenKey]
+                        token = params_instance[self._tokenKey]
                     elif isinstance(params_instance, (int, str, float)):
-                        token= params_instance
+                        token = params_instance
                     else:
-                        token= getattr(params_instance, self._tokenKey)
+                        token = getattr(params_instance, self._tokenKey)
                     if token:
                         if self._rpc:
-                            validate_ret= self._rpc.call(self._rpc_key,**{"token":token,"event":_handleName})
+                            validate_ret = self._rpc.call(
+                                _handleName, **{"token": token, "event": _handleName})
                             if validate_ret:
-                                if validate_ret['state']==200:
-                                    validate_state= True
+                                if validate_ret['state'] == 200:
+                                    validate_state = True
                                 else:
-                                    validate_state= False
+                                    return Response("access error.(%s)" % validate_ret['msg'])
                             else:
-                                validate_state= False
+                                return Response("access http error.")
                         else:
                             return Response("rpc handle is none.", status=404)
                     else:
-                        validate_state= False
+                        return Response("token(%s) is None.")
                 if validate_state:
                     ret = func(*args, **kwargs)
                     return ret
